Introduction — mujpy.mujpy 1.05 documentation

# Introduction

Welcome to mujpy v.2.7.3, the jupyterlab notebook interface for muon spin spectroscopy analysis. This suite is based loosely on the general layout of the Matlab mulab interface and on contamination of ideas with musrfit by Andreas Suter.

Mujpy has just been refactored in version 2.0. As of v. 2.7.3 it comes with:

> - a number of “Tst_mrun…” jupyter notebook examples that can be used as templates for existing categories of fits
>     - TF \(\alpha\) calibration on single run
>     - fit on a single run
>     - sequential fits on a suite of runs
>     - sequential fits on a single run, distinct groups of detectors
>     - global fit on a single run, distinct groups of detectors
>     - sequential fits on multiple runs
>     - global fit on multiple runs, single group of detectors
>     - yet to come global fit on multiple runs, multiple detectors

It comes with a Graphical User Interface (gui), or Dashboard, mimicking and extending mulab, meant to be intuitive for the experienced MuSR user.

> - a smaller number of MuDash jupyter notebook examples to start the gui
> - the Dashboard features unobtrusive tiptools: hovering with the mouse overt the descriptive text or the buttons additional instructions appear.

You must be familiar with standard MuSR concepts such as the \(\alpha\) calibration factor, or the muon asymmetry.

Refer to a muon primer, such as [Blundell], also at arXiv or to a textbook, like [BDLP] or [Yaouanc] for this purpose.

Caution: tutorial for v. 2.7.3 is work-in-progress. The example notebooks themselved clarify the way to use mujpy and it is briefly commented in Reference.

You can find more detailed description of the different mujpy methods in the Reference.

[BDLP] | S.J. Blundell, R. De Renzi, T. Lancaster and F. Pratt, Muon spin spectroscopy, OUP 2021

[Blundell] | S.J. Blundell, Contemporary Physics 40, 175-192 (1999)

[Yaouanc] | Yaouanc and P. Dalmas de Reotier, MUON SPIN ROTATION, RELAXATION and RESONANCE, Oxford University Press, 2011